==> struts2-jquery-grid-plugin-3.7.0-sources.jar: com/jgeppert/struts2/jquery/grid/views/freemarker/tags/JqueryGridModels.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package com.jgeppert.struts2.jquery.grid.views.freemarker.tags;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.opensymphony.xwork2.util.ValueStack;

/**
 * 
 * @author <a href="http://www.jgeppert.com">Johannes Geppert</a>
 * 
 */
public class JqueryGridModels {
  protected GridColumnModel   gridColumn;
  protected GridModel         grid;

  private ValueStack          stack;
  private HttpServletRequest  req;
  private HttpServletResponse res;

  public JqueryGridModels(ValueStack stack, HttpServletRequest req, HttpServletResponse res) {
    this.stack = stack;
    this.req = req;
    this.res = res;
  }

  public GridColumnModel getGridColumn()
  {
    if (gridColumn == null)
    {
      gridColumn = new GridColumnModel(stack, req, res);
    }

    return gridColumn;
  }

  public GridModel getGrid()
  {
    if (grid == null)
    {
      grid = new GridModel(stack, req, res);
    }

    return grid;
  }
}

==> struts2-jquery-grid-plugin-4.0.2-sources.jar: com/jgeppert/struts2/jquery/grid/views/freemarker/tags/JqueryGridModels.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package com.jgeppert.struts2.jquery.grid.views.freemarker.tags;

import com.opensymphony.xwork2.util.ValueStack;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * @author <a href="http://www.jgeppert.com">Johannes Geppert</a>
 */
public class JqueryGridModels {
    protected GridColumnModel gridColumn;
    protected GridModel grid;

    private ValueStack stack;
    private HttpServletRequest req;
    private HttpServletResponse res;

    public JqueryGridModels(ValueStack stack, HttpServletRequest req, HttpServletResponse res) {
        this.stack = stack;
        this.req = req;
        this.res = res;
    }

    public GridColumnModel getGridColumn() {
        if (gridColumn == null) {
            gridColumn = new GridColumnModel(stack, req, res);
        }

        return gridColumn;
    }

    public GridModel getGrid() {
        if (grid == null) {
            grid = new GridModel(stack, req, res);
        }

        return grid;
    }
}
